@@ -27,7 +27,7 @@ from .jsonrpc.protocol import (
 
 # Package metadata
 __author__ = "Khader-X"
-__email__ = "khader.x@example.com"
+__email__ = "contact@khaderx.com"
 __description__ = "Python-Flutter bridge using JSON-RPC"
 
 # Export main decorator and components
